import com.sun.messaging.ConnectionConfiguration;
import com.sun.messaging.ConnectionFactory;
import org.junit.After;
import org.junit.Before;
import org.junit.Test;

import javax.jms.Connection;
import javax.jms.JMSException;
import javax.jms.Message;
import javax.jms.MessageProducer;
import javax.jms.Queue;
import javax.jms.Session;


public class Test_SendJmsMessage {

    private static final String MQ_ADDRESS = "mq://localhost:7676/";
    //asadmin create-jms-resource --restype javax.jms.Queue TestQueue
    private static final String QUEUE_NAME = "TestQueue";
    private Connection      connection;
    private MessageProducer sender;
    private Session         session;



    @Before
    public void setup()
            throws JMSException {

        final ConnectionFactory connectionFactory = new com.sun.messaging.QueueConnectionFactory();
        connectionFactory.setProperty( ConnectionConfiguration.imqAddressList, MQ_ADDRESS );


        connection = connectionFactory.createConnection();


        session = connection.createSession( false, Session.AUTO_ACKNOWLEDGE );

        Queue queue = session.createQueue( QUEUE_NAME );
        sender = session.createProducer( queue );
    }



    @After
    public void tearDown()
            throws JMSException {
        if ( connection != null ) {
            connection.close();
        }
    }



    @Test
    /**
     * Only works when LOCAL or REMOTE broker is used.
     * Exception in Glassfish log:
     * MQJMSRA_DM4001: :Exception:ObjectMessage.getObject()DeSerializing object::message=invalid stream header: 789C5BF3
     */
    public void sendCompressedJmsMessage()
            throws JMSException {


        Message message = session.createObjectMessage( new String( "Hello my friend. Stay awhile and listen..." ) );
        message.setBooleanProperty( "JMS_SUN_COMPRESS", true );

        sender.send( message,
                     sender.getDeliveryMode(),
                     1,
                     sender.getTimeToLive() );


    }



    @Test
    /**
     * Works with every kind of MQ Broker.
     */
    public void sendUncompressedJmsMessage()
            throws JMSException {


        Message message = session.createObjectMessage( new String( "I sense a soul in search of answers..." ) );
        sender.send( message,
                     sender.getDeliveryMode(),
                     1,
                     sender.getTimeToLive() );


    }

}
